km3modules.k40.MedianPMTRatesService
====================================

.. currentmodule:: km3modules.k40

.. autoclass:: MedianPMTRatesService

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MedianPMTRatesService.__init__
      ~MedianPMTRatesService.add
      ~MedianPMTRatesService.configure
      ~MedianPMTRatesService.expose
      ~MedianPMTRatesService.finish
      ~MedianPMTRatesService.get
      ~MedianPMTRatesService.get_median_rates
      ~MedianPMTRatesService.pre_finish
      ~MedianPMTRatesService.process
      ~MedianPMTRatesService.require
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MedianPMTRatesService.name
   
   